@@ -14,7 +14,7 @@ my $DEFAULT_VERSION = '23';
 my $CRLF = "\015\012";
 
 require Crypt::SSLeay;
-$VERSION = '2.77';
+$VERSION = '2.78';
 
 sub _default_context
 {
@@ -53,6 +53,18 @@ sub configure
     *$self->{'ssl_new_arg'} = $NEW_ARGS;
     *$self->{'ssl_peer_verify'} = 0;
 
+    ## Crypt::SSLeay must also aware the SSL Proxy before calling
+    ## $socket->configure($args). Because the $sock->configure() will
+    ## die when failed to resolve the destination server IP address,
+    ## whatever the SSL proxy is used or not!
+    ## - dqbai, 2003-05-10
+    if (my $proxy = $self->proxy) {
+	my ($host, $port) = split(':',$proxy);
+	$port || die("no port given for proxy server $proxy");
+	$arg->{PeerAddr} = $host;
+	$arg->{PeerPort} = $port;
+    }
+
     $self->SUPER::configure($arg);
 }
 
@@ -395,6 +407,7 @@ sub configure_certs {
 	my $file = $ENV{$_};
 	if($file) {
 	    (-e $file) or die("$file file does not exist: $!");
+	    (-r $file) or die("$file file is not readable");
 	    $count++;
 	    if (/PKCS12/) {
 		$count++;
